@@ -5,7 +5,7 @@ class UploadJob:
                  set_date_conversion=None, set_logging=None, set_clear_csv_cache=None,
                  first_name=None, surname=None):
         self.start_time = dt.datetime.now()
-        self.upload_details = {}
+        self.upload_details = {'Error': ''}
         self.thg_log()
         self.account = Account(first_name, surname)
         self.upload_setting = UploadSettings(set_date_conversion, set_logging, set_clear_csv_cache)
@@ -15,6 +15,7 @@ class UploadJob:
         self.table_name = table_name
         self.save_file_path = self.get_save_file_path(save_file_path)
         self.schema = schema
+        self.get_schema()
         self.date_column = date_column
         self.credentials = self.get_credentials()
         self.csv = csv
@@ -224,6 +225,21 @@ class UploadJob:
                 self.log('Converting SQL ODBC connecting from {} to {}'.format(self.dsn, 'CustomerProfiling_NewDWH'))
                 self.dsn = 'CustomerProfiling_NewDWH'
 
+    def get_schema(self):
+        self.upload_details['Progress'] = 'Getting Schema'
+        if self.schema is not None:
+            temp_schema = []
+            try:
+                for i in self.schema:
+                    name = i[0]
+                    field_type = i[1]
+                    temp_schema.append(sf(name=name, field_type=field_type, mode="NULLABLE"))
+                self.schema = temp_schema
+            except Exception as e:
+                self.log('Error: {}'.format(e))
+                self.upload_details['Error'] = e
+        pass
+
     def get_data_frame(self):
         self.upload_details['Progress'] = 'Getting dataframe.'
         start_time = dt.datetime.now()
@@ -411,7 +427,6 @@ class UploadJob:
         finally:
             self.get_upload_details()
             if self.upload_details['Error'] != '':
-                print('lol')
                 self.send_email()
             if self.upload_setting.vm_status:
                 self.log('Logging Upload to BQ')
